==> haskell-either-4.4.1-15-armv7h.pkg.tar.xz: usr/share/haskell/haskell-either/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1
id: either-4.4.1-02b52c35841743771b37e0d5948e3cc8
key: eithe_3kiXOfQlXWi4ztU2aTsPak
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/either-4.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/either-4.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/either-4.4.1
hs-libraries: HSeither-4.4.1-3kiXOfQlXWi4ztU2aTsPak
depends:
    MonadRandom-0.4.2.2-41c453a4d3603a1aafaf1f31fe6ac694
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.2.1-3dea194c07c9b02982b78a82398333cc
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    free-4.12.4-a5ffddbbf41dcb5e4b11e5d62a21f456
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    profunctors-5.2-aaf86384a4db0133740cbda80ff5e59a
    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-4.4.1-19-armv7h.pkg.tar.xz: usr/share/haskell/haskell-either/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1
id: either-4.4.1-034f73c037cf6acbd6a0e4686245d294
key: eithe_BDwvL4nQ38T3cnSQxj11aV
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/either-4.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/either-4.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/either-4.4.1
hs-libraries: HSeither-4.4.1-BDwvL4nQ38T3cnSQxj11aV
depends:
    MonadRandom-0.4.2.2-41c453a4d3603a1aafaf1f31fe6ac694
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.3-332d0b68f126b9a85f3a8ae905feb67c
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    free-4.12.4-5e68614777ed20792496ad931a527625
    mmorph-1.0.6-1a509ce4d7b5bdf9a92707e79b8069c6
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    profunctors-5.2-1a11bf84af8321e4318303d34ccac042
    semigroupoids-5.0.1-9020d584fd071e35efe756eb398e9c78
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
